bodhi.server.models — bodhi 4.0.0 documentation

# bodhi.server.models

Bodhi’s database models.

Classes

`BodhiBase` | Base class for the SQLAlchemy model base class.
`Bug`(**kwargs) | Represents a Bugzilla bug.
`BugKarma`(**kwargs) | Karma for a bug associated with a comment.
`Build`(**kwargs) | This model represents a specific build of a package.
`BuildrootOverride`(**kwargs) | This model represents a Koji buildroot override.
`Comment`(**kwargs) | An update comment.
`Compose`(**kwargs) | Express the status of an in-progress compose job.
`ComposeState` | Define the various states that a `Compose` can be in.
`ContainerBuild`(**kwargs) | Represents a Container build.
`ContainerPackage`(**kwargs) | Represents a Container package.
`ContentType` | Used to differentiate between different kinds of content in various models.
`DeclEnum` | Declarative enumeration.
`DeclEnumType`(enum) | A database column type for an enum.
`EnumMeta`(classname, bases, dict_) | Generate new DeclEnum classes.
`EnumSymbol`(cls_, name, value, description) | Define a fixed symbol tied to a parent class.
`FlatpakBuild`(**kwargs) | Represents a Flatpak build.
`FlatpakPackage`(**kwargs) | Represents a Flatpak package.
`Group`(**kwargs) | A group of users.
`ModuleBuild`(**kwargs) | Represents a Module build.
`ModulePackage`(**kwargs) | Represents a Module package.
`Package`(**kwargs) | This model represents a package.
`Release`(**kwargs) | Represent a distribution release, such as Fedora 27.
`ReleaseState` | An enum that describes the state of a `Release`.
`RpmBuild`(**kwargs) | Represents an RPM build.
`RpmPackage`(**kwargs) | Represents a RPM package.
`TestCase`(**kwargs) | Represents test cases from the wiki.
`TestCaseKarma`(**kwargs) | Karma for a TestCase associated with a comment.
`TestGatingStatus` | This class lists the different status the `Update.test_gating_status` flag can have.
`Update`(*args, **kwargs) | This model represents an update.
`UpdateRequest` | An enum used to specify an update requesting to change states.
`UpdateSeverity` | An enum used to specify the severity of the update.
`UpdateStatus` | An enum used to describe the current state of an update.
`UpdateSuggestion` | An enum used to tell the user whether they need to reboot or logout after applying an update.
`UpdateType` | An enum used to classify the type of the update.
`User`(**kwargs) | A Bodhi user.